summaryrefslogtreecommitdiff
path: root/svx/source/svdraw
diff options
context:
space:
mode:
authorrocso <ross.johnson@homemail.com.au>2021-09-17 17:12:37 +1000
committerHeiko Tietze <heiko.tietze@documentfoundation.org>2021-09-17 12:53:38 +0200
commit4f7560240d8a9273fd5ecbc76e7ac054b3a6e4ae (patch)
treee60ece962e82d692568e1ffbb3a54ee9a6d5865a /svx/source/svdraw
parent74691a6f1b4aaadfed284ba9746032e438f7468b (diff)
tdf#143550 - use the term "gluepoints" consistently
Change-Id: Id10dc2ef13f54a148a800003cc4bd88ca1a0056f Reviewed-on: https://gerrit.libreoffice.org/c/core/+/122233 Tested-by: Jenkins Reviewed-by: Heiko Tietze <heiko.tietze@documentfoundation.org>
Diffstat (limited to 'svx/source/svdraw')
-rw-r--r--svx/source/svdraw/svdcrtv.cxx2
-rw-r--r--svx/source/svdraw/svddrgmt.cxx2
-rw-r--r--svx/source/svdraw/svddrgv.cxx4
-rw-r--r--svx/source/svdraw/svdglue.cxx4
-rw-r--r--svx/source/svdraw/svdhdl.cxx2
-rw-r--r--svx/source/svdraw/svdmrkv.cxx2
-rw-r--r--svx/source/svdraw/svdmrkv1.cxx4
-rw-r--r--svx/source/svdraw/svdobj.cxx12
-rw-r--r--svx/source/svdraw/svdoedge.cxx12
-rw-r--r--svx/source/svdraw/svdview.cxx4
10 files changed, 24 insertions, 24 deletions
diff --git a/svx/source/svdraw/svdcrtv.cxx b/svx/source/svdraw/svdcrtv.cxx
index 67820ff1d732..9d6dc71b7d4f 100644
--- a/svx/source/svdraw/svdcrtv.cxx
+++ b/svx/source/svdraw/svdcrtv.cxx
@@ -81,7 +81,7 @@ ImplConnectMarkerOverlay::ImplConnectMarkerOverlay(const SdrCreateView& rView, S
xTargetOverlay->add(*pNew);
maObjects.append(std::move(pNew));
- // glue points
+ // gluepoints
for(sal_uInt16 i(0); i < 4; i++)
{
SdrGluePoint aGluePoint(rObject.GetVertexGluePoint(i));
diff --git a/svx/source/svdraw/svddrgmt.cxx b/svx/source/svdraw/svddrgmt.cxx
index 17376206f8a7..5917d1475c44 100644
--- a/svx/source/svdraw/svddrgmt.cxx
+++ b/svx/source/svdraw/svddrgmt.cxx
@@ -1621,7 +1621,7 @@ void SdrDragMove::MoveSdrDrag(const Point& rNoSnapPnt_)
}
if (getSdrDragView().IsDraggingGluePoints())
- { // restrict glue points to the BoundRect of the Obj
+ { // restrict gluepoints to the BoundRect of the Obj
aPt1-=DragStat().GetStart();
const SdrMarkList& rML=GetMarkedObjectList();
const size_t nMarkCount=rML.GetMarkCount();
diff --git a/svx/source/svdraw/svddrgv.cxx b/svx/source/svdraw/svddrgv.cxx
index b5a8025a51d5..b6ac05cef7c1 100644
--- a/svx/source/svdraw/svddrgv.cxx
+++ b/svx/source/svdraw/svddrgv.cxx
@@ -619,7 +619,7 @@ void SdrDragView::BrkDragObj()
if (IsInsertGluePoint())
{
- mpInsPointUndo->Undo(); // delete inserted glue point again
+ mpInsPointUndo->Undo(); // delete inserted gluepoint again
delete mpInsPointUndo;
mpInsPointUndo=nullptr;
SetInsertGluePoint(false);
@@ -781,7 +781,7 @@ bool SdrDragView::BegInsGluePoint(const Point& rPnt)
}
else
{
- // no glue points possible for this object (e. g. Edge)
+ // no gluepoints possible for this object (e. g. Edge)
SetInsertGluePoint(false);
delete mpInsPointUndo;
mpInsPointUndo=nullptr;
diff --git a/svx/source/svdraw/svdglue.cxx b/svx/source/svdraw/svdglue.cxx
index 59576ea01a69..7f25074cf425 100644
--- a/svx/source/svdraw/svdglue.cxx
+++ b/svx/source/svdraw/svdglue.cxx
@@ -290,8 +290,8 @@ SdrGluePointList& SdrGluePointList::operator=(const SdrGluePointList& rSrcList)
return *this;
}
-// The ID's of the glue points always increase monotonously!
-// If an ID is taken already, the new glue point gets a new ID. ID 0 is reserved.
+// The ID's of the gluepoints always increase monotonously!
+// If an ID is taken already, the new gluepoint gets a new ID. ID 0 is reserved.
sal_uInt16 SdrGluePointList::Insert(const SdrGluePoint& rGP)
{
SdrGluePoint aGP(rGP);
diff --git a/svx/source/svdraw/svdhdl.cxx b/svx/source/svdraw/svdhdl.cxx
index 85d46f99a00e..ed0331c24a38 100644
--- a/svx/source/svdraw/svdhdl.cxx
+++ b/svx/source/svdraw/svdhdl.cxx
@@ -1041,7 +1041,7 @@ bool SdrHdl::IsFocusHdl() const
case SdrHdlKind::Circle: // angle of circle segments, corner radius of rectangles
case SdrHdlKind::Ref1: // reference point 1, e. g. center of rotation
case SdrHdlKind::Ref2: // reference point 2, e. g. endpoint of reflection axis
- case SdrHdlKind::Glue: // glue point
+ case SdrHdlKind::Glue: // gluepoint
// for SJ and the CustomShapeHandles:
case SdrHdlKind::CustomShape1:
diff --git a/svx/source/svdraw/svdmrkv.cxx b/svx/source/svdraw/svdmrkv.cxx
index 442719ad15e8..456ffd30f7fd 100644
--- a/svx/source/svdraw/svdmrkv.cxx
+++ b/svx/source/svdraw/svdmrkv.cxx
@@ -1792,7 +1792,7 @@ void SdrMarkView::CheckMarked()
}
else
{
- if (!IsGluePointEditMode()) { // selected glue points only in GlueEditMode
+ if (!IsGluePointEditMode()) { // selected gluepoints only in GlueEditMode
SdrUShortCont& rPts = pM->GetMarkedGluePoints();
rPts.clear();
}
diff --git a/svx/source/svdraw/svdmrkv1.cxx b/svx/source/svdraw/svdmrkv1.cxx
index 89ec0c5dc199..0c32aefcfd11 100644
--- a/svx/source/svdraw/svdmrkv1.cxx
+++ b/svx/source/svdraw/svdmrkv1.cxx
@@ -322,7 +322,7 @@ void SdrMarkView::UndirtyMrkPnt() const
SdrUShortCont& rPts = pM->GetMarkedGluePoints();
const SdrGluePointList* pGPL=pObj->GetGluePointList();
if (pGPL!=nullptr) {
- // Remove invalid selected glue points, that is, all entries
+ // Remove invalid selected gluepoints, that is, all entries
// (IDs) that aren't contained in the GluePointList of the
// object
for(SdrUShortCont::const_iterator it = rPts.begin(); it != rPts.end(); )
@@ -337,7 +337,7 @@ void SdrMarkView::UndirtyMrkPnt() const
}
} else {
if (!rPts.empty()) {
- rPts.clear(); // object doesn't have any glue points (any more)
+ rPts.clear(); // object doesn't have any gluepoints (any more)
bChg=true;
}
}
diff --git a/svx/source/svdraw/svdobj.cxx b/svx/source/svdraw/svdobj.cxx
index 27c2fb50b6c2..05f7712c0431 100644
--- a/svx/source/svdraw/svdobj.cxx
+++ b/svx/source/svdraw/svdobj.cxx
@@ -1912,7 +1912,7 @@ void SdrObject::SaveGeoData(SdrObjGeoData& rGeo) const
rGeo.bClosedObj =m_bClosedObj ;
rGeo.mnLayerID = mnLayerID;
- // user-defined glue points
+ // user-defined gluepoints
if (m_pPlusData!=nullptr && m_pPlusData->pGluePoints!=nullptr) {
if (rGeo.pGPL!=nullptr) {
*rGeo.pGPL=*m_pPlusData->pGluePoints;
@@ -1936,7 +1936,7 @@ void SdrObject::RestoreGeoData(const SdrObjGeoData& rGeo)
m_bClosedObj =rGeo.bClosedObj ;
mnLayerID = rGeo.mnLayerID;
- // user-defined glue points
+ // user-defined gluepoints
if (rGeo.pGPL!=nullptr) {
ImpForcePlusData();
if (m_pPlusData->pGluePoints!=nullptr) {
@@ -2303,7 +2303,7 @@ SdrGluePointList* SdrObject::ForceGluePointList()
void SdrObject::SetGlueReallyAbsolute(bool bOn)
{
- // First a const call to see whether there are any glue points.
+ // First a const call to see whether there are any gluepoints.
// Force const call!
if (GetGluePointList()!=nullptr) {
SdrGluePointList* pGPL=ForceGluePointList();
@@ -2313,7 +2313,7 @@ void SdrObject::SetGlueReallyAbsolute(bool bOn)
void SdrObject::NbcRotateGluePoints(const Point& rRef, Degree100 nAngle, double sn, double cs)
{
- // First a const call to see whether there are any glue points.
+ // First a const call to see whether there are any gluepoints.
// Force const call!
if (GetGluePointList()!=nullptr) {
SdrGluePointList* pGPL=ForceGluePointList();
@@ -2323,7 +2323,7 @@ void SdrObject::NbcRotateGluePoints(const Point& rRef, Degree100 nAngle, double
void SdrObject::NbcMirrorGluePoints(const Point& rRef1, const Point& rRef2)
{
- // First a const call to see whether there are any glue points.
+ // First a const call to see whether there are any gluepoints.
// Force const call!
if (GetGluePointList()!=nullptr) {
SdrGluePointList* pGPL=ForceGluePointList();
@@ -2333,7 +2333,7 @@ void SdrObject::NbcMirrorGluePoints(const Point& rRef1, const Point& rRef2)
void SdrObject::NbcShearGluePoints(const Point& rRef, double tn, bool bVShear)
{
- // First a const call to see whether there are any glue points.
+ // First a const call to see whether there are any gluepoints.
// Force const call!
if (GetGluePointList()!=nullptr) {
SdrGluePointList* pGPL=ForceGluePointList();
diff --git a/svx/source/svdraw/svdview.cxx b/svx/source/svdraw/svdview.cxx
index f61c1cb7c852..37dc5a8bb1c8 100644
--- a/svx/source/svdraw/svdview.cxx
+++ b/svx/source/svdraw/svdview.cxx
@@ -336,7 +336,7 @@ SdrHitKind SdrView::PickAnything(const Point& rLogicPos, SdrViewEvent& rVEvt) co
}
else if (bGluePointMode && PickGluePoint(aLocalLogicPosition,pObj,nGlueId,pPV))
{
- eHit=SdrHitKind::Gluepoint; // deselected glue point hit
+ eHit=SdrHitKind::Gluepoint; // deselected gluepoint hit
}
else if ((pHitObj = PickObj(aLocalLogicPosition,mnHitTolLog,pPV,SdrSearchOptions::DEEP|SdrSearchOptions::MARKED,&pObj,&bHitPassDirect)))
{
@@ -805,7 +805,7 @@ bool SdrView::DoMouseEvent(const SdrViewEvent& rVEvt)
if (!MarkObj(aLogicPos, mnHitTolLog, rVEvt.mbAddMark))
{
// No object hit. Do the following:
- // 1. deselect any selected glue points
+ // 1. deselect any selected gluepoints
// 2. deselect any selected polygon points
// 3. deselect any selected objects
if (!rVEvt.mbAddMark) UnmarkAll();
diff --git a/svx/source/svdraw/svdoedge.cxx b/svx/source/svdraw/svdoedge.cxx
index c48d954c9ace..45e4329a54a8 100644
--- a/svx/source/svdraw/svdoedge.cxx
+++ b/svx/source/svdraw/svdoedge.cxx
@@ -460,12 +460,12 @@ SdrGluePoint SdrEdgeObj::GetCornerGluePoint(sal_uInt16 nNum) const
const SdrGluePointList* SdrEdgeObj::GetGluePointList() const
{
- return nullptr; // no user defined glue points for connectors
+ return nullptr; // no user defined gluepoints for connectors
}
SdrGluePointList* SdrEdgeObj::ForceGluePointList()
{
- return nullptr; // no user defined glue points for connectors
+ return nullptr; // no user defined gluepoints for connectors
}
void SdrEdgeObj::ConnectToNode(bool bTail1, SdrObject* pObj)
@@ -2553,10 +2553,10 @@ void SdrEdgeObj::SetTailPoint( bool bTail, const Point& rPt )
SetChanged();
}
/** this method is used by the api to set a glue point for a connection
nId == -1 : The best default point is automatically chosen
0 <= nId <= 3 : One of the default points is chosen
- nId >= 4 : A user defined glue point is chosen
+ nId >= 4 : A user defined gluepoint is chosen
*/
void SdrEdgeObj::setGluePointIndex( bool bTail, sal_Int32 nIndex /* = -1 */ )
{
@@ -2570,7 +2570,7 @@ void SdrEdgeObj::setGluePointIndex( bool bTail, sal_Int32 nIndex /* = -1 */ )
{
nIndex -= 3; // the start api index is 0, whereas the implementation in svx starts from 1
- // for user defined glue points we have
+ // for user defined gluepoints we have
// to get the id for this index first
const SdrGluePointList* pList = rConn1.GetObject() ? rConn1.GetObject()->GetGluePointList() : nullptr;
if( pList == nullptr || SDRGLUEPOINT_NOTFOUND == pList->FindGluePoint(static_cast<sal_uInt16>(nIndex)) )
@@ -2588,7 +2588,7 @@ void SdrEdgeObj::setGluePointIndex( bool bTail, sal_Int32 nIndex /* = -1 */ )
ImpRecalcEdgeTrack();
}
/** this method is used by the api to return a glue point id for a connection.
See setGluePointId for possible return values */
sal_Int32 SdrEdgeObj::getGluePointIndex( bool bTail )
{
@@ -2553,10 +2553,10 @@ void SdrEdgeObj::SetTailPoint( bool bTail, const Point& rPt )
SetChanged();
}
-/** this method is used by the api to set a glue point for a connection
+/** this method is used by the api to set a gluepoint for a connection
nId == -1 : The best default point is automatically chosen
0 <= nId <= 3 : One of the default points is chosen
@@ -2588,7 +2588,7 @@ void SdrEdgeObj::setGluePointIndex( bool bTail, sal_Int32 nIndex /* = -1 */ )
ImpRecalcEdgeTrack();
}
-/** this method is used by the api to return a glue point id for a connection.
+/** this method is used by the api to return a gluepoint id for a connection.
See setGluePointId for possible return values */
sal_Int32 SdrEdgeObj::getGluePointIndex( bool bTail )